@@ -17,69 +17,72 @@ limitations under the License.
  */
 
 //a Imports
-use crate::{Num, Float};
 use crate::vector_op as vector;
+use crate::{Float, Num};
 
 //a Constructors
 //fp zero
 /// Crate a new matrix which is all zeros
-pub fn zero<V:Num,const RC:usize> () -> [V; RC] { [V::zero();RC] }
+pub fn zero<V: Num, const RC: usize>() -> [V; RC] {
+    [V::zero(); RC]
+}
 
 //mp set_zero
 /// Set the matrix to have all elements of zero
-pub fn set_zero<V:Num> (m:&mut [V]) {
+pub fn set_zero<V: Num>(m: &mut [V]) {
     vector::set_zero(m)
 }
 
 //fp is_zero
 /// Return true if the matrix is all zeros
-pub fn is_zero<V:Num> (m:&[V]) -> bool {
+pub fn is_zero<V: Num>(m: &[V]) -> bool {
     vector::is_zero(m)
 }
 
 //cp scale
 /// Consume the vector and return a new vector that is the original
 /// scaled in each coordinate a single scaling factor
-pub fn scale<V:Num,const RC:usize> (m:[V;RC], s:V) -> [V;RC] {
+pub fn scale<V: Num, const RC: usize>(m: [V; RC], s: V) -> [V; RC] {
     vector::scale(m, s)
 }
 
 //cp reduce
 /// Consume the vector and return a new vector that is the original
 /// reduces in scale in each coordinate by a single scaling factor
-pub fn reduce<V:Num,const RC:usize> (m:[V;RC], s:V) -> [V;RC] {
+pub fn reduce<V: Num, const RC: usize>(m: [V; RC], s: V) -> [V; RC] {
     vector::reduce(m, s)
 }
 
 //cp add
 /// Consume the vector, and return a new vector that is the sum of
 /// this and a borrowed other vector scaled
-pub fn add<V:Num,const RC:usize> (m:[V;RC], other:&[V;RC], scale:V) -> [V;RC] {
+pub fn add<V: Num, const RC: usize>(m: [V; RC], other: &[V; RC], scale: V) -> [V; RC] {
     vector::add(m, other, scale)
 }
 
 //cp sub
 /// Consume the vector, and return a new vector that is the difference of
 /// this and a borrowed other vector scaled
-pub fn sub<V:Num,const RC:usize> (m:[V;RC], other:&[V;RC], scale:V) -> [V;RC] {
+pub fn sub<V: Num, const RC: usize>(m: [V; RC], other: &[V; RC], scale: V) -> [V; RC] {
     vector::sub(m, other, scale)
 }
 
 //cp absmax
 /// Consume the vector, and return a new vector that is the sum of
 /// this and a borrowed other vector scaled
-pub fn absmax<V:Float> (m:&[V]) -> V {
-    m.iter().fold(V::zero(), |acc, c| V::max(acc,V::abs(*c)))
+pub fn absmax<V: Float>(m: &[V]) -> V {
+    m.iter().fold(V::zero(), |acc, c| V::max(acc, V::abs(*c)))
 }
 
 //cp normalize
 /// Update the new matrix with every element e scaled so that max(abs(e)) is 1.
-pub fn normalize<V:Float,const RC:usize,const C:usize> (mut m:[V;RC]) -> [V;RC] {
+pub fn normalize<V: Float, const RC: usize, const C: usize>(mut m: [V; RC]) -> [V; RC] {
     let l = absmax::<V>(&m);
     if l < V::epsilon() {
-        set_zero::<V>(&mut m); m
+        set_zero::<V>(&mut m);
+        m
     } else {
-        reduce::<V,RC>(m, l)
+        reduce::<V, RC>(m, l)
     }
 }
 
@@ -89,12 +92,12 @@ pub fn normalize<V:Float,const RC:usize,const C:usize> (mut m:[V;RC]) -> [V;RC]
 /// The matrices are row-major, so successive entries of m are adjacent columns
 ///
 /// The output matrix has adjacent entries that are therefore adjacent rows in m
-pub fn transpose<V:Float,const RC:usize,const R:usize,const C:usize> (m:[V;RC]) -> [V;RC] {
-    assert_eq!(RC, R*C);
-    let mut v = zero::<V,RC>();
+pub fn transpose<V: Float, const RC: usize, const R: usize, const C: usize>(m: [V; RC]) -> [V; RC] {
+    assert_eq!(RC, R * C);
+    let mut v = zero::<V, RC>();
     for r in 0..R {
         for c in 0..C {
-            v[r+c*R] = m[c+r*C];
+            v[r + c * R] = m[c + r * C];
         }
     }
     v
@@ -102,18 +105,29 @@ pub fn transpose<V:Float,const RC:usize,const R:usize,const C:usize> (m:[V;RC])
 
 //mp multiply
 /// Multiply two matrices
-pub fn multiply<V:Float,const RX:usize, const XC:usize, const RC:usize, const R:usize, const X:usize, const C:usize> (a:&[V;RX], b:&[V;XC]) -> [V;RC] {
-    assert_eq!(RX, R*X);
-    assert_eq!(RC, R*C);
-    assert_eq!(XC, X*C);
-    let mut m = [V::zero();RC];
+pub fn multiply<
+    V: Float,
+    const RX: usize,
+    const XC: usize,
+    const RC: usize,
+    const R: usize,
+    const X: usize,
+    const C: usize,
+>(
+    a: &[V; RX],
+    b: &[V; XC],
+) -> [V; RC] {
+    assert_eq!(RX, R * X);
+    assert_eq!(RC, R * C);
+    assert_eq!(XC, X * C);
+    let mut m = [V::zero(); RC];
     for r in 0..R {
         for c in 0..C {
             let mut v = V::zero();
             for x in 0..X {
-                v = v + a[r*X+x]*b[x*C+c];
+                v = v + a[r * X + x] * b[x * C + c];
             }
-            m[r*C+c] = v;
+            m[r * C + c] = v;
         }
     }
     m
@@ -121,8 +135,11 @@ pub fn multiply<V:Float,const RX:usize, const XC:usize, const RC:usize, const R:
 
 //mp transform_vec
 /// Transform a vector
-pub fn transform_vec<V:Float,const RD:usize,const R:usize,const D:usize> (m:&[V;RD], v:&[V;D]) -> [V;R] {
-    multiply::<V,RD,D,R,R,D,1> (m, v)
+pub fn transform_vec<V: Float, const RD: usize, const R: usize, const D: usize>(
+    m: &[V; RD],
+    v: &[V; D],
+) -> [V; R] {
+    multiply::<V, RD, D, R, R, D, 1>(m, v)
 }
 
 //a Formatting
@@ -145,18 +162,20 @@ pub fn transform_vec<V:Float,const RD:usize,const R:usize,const D:usize> (m:&[V;
 /// }
 /// assert_eq!( format!("{}", &Mat{c:[0., 1., 2., 3., 4., 5.]} ), "[0,1 2,3 4,5]" );
 /// ```
-pub fn fmt<V:Num,const C:usize>(f: &mut std::fmt::Formatter, v : &[V]) -> std::fmt::Result {
-    let mut c=0;
+pub fn fmt<V: Num, const C: usize>(f: &mut std::fmt::Formatter, v: &[V]) -> std::fmt::Result {
+    let mut c = 0;
     for i in 0..v.len() {
-        if i==0 {
+        if i == 0 {
             write!(f, "[{}", v[i])?;
-        } else if c==0 {
+        } else if c == 0 {
             write!(f, " {}", v[i])?;
         } else {
             write!(f, ",{}", v[i])?;
         }
         c += 1;
-        if c == C { c=0; }
+        if c == C {
+            c = 0;
+        }
     }
     write!(f, "]")
 }
@@ -174,20 +193,24 @@ pub fn fmt<V:Num,const C:usize>(f: &mut std::fmt::Formatter, v : &[V]) -> std::f
 /// ```
 ///
 #[derive(Debug)]
-pub struct MatrixType<'a, V:Num,const RC:usize,const C:usize>  {
+pub struct MatrixType<'a, V: Num, const RC: usize, const C: usize> {
     /// Contents of the matrix
-    m : &'a [V;RC],
+    m: &'a [V; RC],
 }
 
 //ip MatrixType
-impl <'a, V:Num,const RC:usize,const C:usize> MatrixType<'a,V,RC,C> {
+impl<'a, V: Num, const RC: usize, const C: usize> MatrixType<'a, V, RC, C> {
     //fp new
     /// Create a new MatrixType by borrowing an array of Num; this may then be formatted using its Display trait
-    pub fn new(m:&'a [V;RC]) -> Self { Self {m} }
+    pub fn new(m: &'a [V; RC]) -> Self {
+        Self { m }
+    }
 }
 
 //ip Display for MatrixType
-impl <'a, V:Num,const RC:usize,const C:usize> std::fmt::Display for MatrixType<'a,V,RC,C>{
+impl<'a, V: Num, const RC: usize, const C: usize> std::fmt::Display for MatrixType<'a, V, RC, C> {
     //
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result { fmt::<V,C>(f, self.m) }
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        fmt::<V, C>(f, self.m)
+    }
 }
